IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[qIIS_GetUserRestrictions]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[qIIS_GetUserRestrictions]
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 25/09/2015
-- Description:	Gets the restrictions for a user, based on the e-Quip proc of the same name 
-- Called By:	eQuipCloud TBS Project but will be universal
-- Notes:
--		Based on the e-Quip proc of the same name 
-- =======================================================================================================================================
-- History:
-- v1.00	25/09/2015	Philip Brassington		Created
-- v1.01	06/11/2015  Philip Brassington		Added parent site inclusions to match e-Quip version 3.2
-- =======================================================================================================================================

CREATE PROC [dbo].[qIIS_GetUserRestrictions]
	@UserId VARCHAR(50),
	@SqlViewId INT,
	@Sql VARCHAR(8000) OUT 
AS
BEGIN
	SET NOCOUNT ON;

	--
	-- We must have a UserId 
	IF ISNULL(@UserId, '') = ''
	BEGIN
		SELECT @Sql = ''
		RETURN 0
	END

	DECLARE @InclusionSql VARCHAR(8000)
	DECLARE @ExclusionSql VARCHAR(8000)

	DECLARE ViewTablesCsr CURSOR FOR
	SELECT TableName, ExplorerSqlViewTable.PkFieldName 
	FROM ExplorerSqlView INNER JOIN ExplorerSqlViewTable 	
		ON ExplorerSqlView.SqlViewId = ExplorerSqlViewTable.SqlViewId
	WHERE ExplorerSqlView.SqlViewId = @SqlViewId
	ORDER BY Ordinal

	OPEN ViewTablesCsr

	DECLARE @TableName VARCHAR(255)
	DECLARE @PkFieldName VARCHAR(255)
	DECLARE @Pk VARCHAR(50)

	FETCH NEXT FROM ViewTablesCsr
	INTO @TableName, @PkFieldName 
	
	--
	-- FOREACH table in this view ...
	WHILE @@FETCH_STATUS = 0
	BEGIN
		--
		-- Build a list of inclusions for this user on this table
		DECLARE InclusionsCsr CURSOR FOR
		SELECT Pk 
		FROM (GroupRestriction INNER JOIN UserGroupLk ON GroupRestriction.GroupId = UserGroupLk.GroupId)
			INNER JOIN ExplorerEntityType ON GroupRestriction.EntityTypeId = ExplorerEntityType.[Id]
		WHERE UserGroupLk.UserId = @UserId AND TableName = @TableName AND ISNULL(Inclusion, 0) != 0
	
		OPEN InclusionsCsr 

		FETCH NEXT FROM InclusionsCsr
		INTO @Pk

		WHILE @@FETCH_STATUS = 0
		BEGIN
			--
			-- ISNULL(FieldName,'') = 'Value'
			DECLARE @Clause1 VARCHAR(255)
		
			--Changed in e-quip 3.2, updated in IIS proc version 3.
			--SELECT @Clause1 = 'ISNULL(' + @PkFieldName + ',' + CHAR(39) + @Pk + CHAR(39) + ') = ' + CHAR(39) + @Pk + CHAR(39)
			IF @TableName != 'ParentSite'
				SET @Clause1 = 'ISNULL(' + @PkFieldName + ',' + CHAR(39) + CHAR(39) + ') = ' + CHAR(39) + @Pk + CHAR(39)
			ELSE
				SET @Clause1 = 'ISNULL(' + @PkFieldName + ',' + CHAR(39) + CHAR(39) + ') LIKE ' + CHAR(39) + '%/' + RTRIM(@Pk) + '/%' + CHAR(39)

			IF ISNULL(@InclusionSql, '') = ''
				SELECT @InclusionSql = @Clause1
			ELSE
				SELECT @InclusionSql = @InclusionSql + ' OR ' + @Clause1

			FETCH NEXT FROM InclusionsCsr
			INTO @Pk
		END

		CLOSE InclusionsCsr
		DEALLOCATE InclusionsCsr
	
		--
		-- Build a list of exclusions for this user on this table
		DECLARE ExclusionsCsr CURSOR FOR
		SELECT Pk 
		FROM (GroupRestriction INNER JOIN UserGroupLk ON GroupRestriction.GroupId = UserGroupLk.GroupId)
			INNER JOIN ExplorerEntityType ON GroupRestriction.EntityTypeId = ExplorerEntityType.[Id]
		WHERE UserGroupLk.UserId = @UserId AND TableName = @TableName AND ISNULL(Inclusion, 0) = 0

		OPEN ExclusionsCsr 

		FETCH NEXT FROM ExclusionsCsr
		INTO @Pk

		WHILE @@FETCH_STATUS = 0
		BEGIN
			--
			-- ISNULL(FieldName,'') = 'Value'
			DECLARE @Clause2 VARCHAR(255)
			SELECT @Clause2 = 'ISNULL(' + @PkFieldName + ',' + CHAR(39) + CHAR(39) + ') != ' + CHAR(39) + @Pk + CHAR(39)

			IF ISNULL(@ExclusionSql, '') = ''
				SELECT @ExclusionSql = @Clause2
			ELSE
				SELECT @ExclusionSql = @ExclusionSql + ' AND ' + @Clause2

			FETCH NEXT FROM ExclusionsCsr
			INTO @Pk
		END

		CLOSE ExclusionsCsr
		DEALLOCATE ExclusionsCsr

		--
		-- Get the next table in this view
		FETCH NEXT FROM ViewTablesCsr
		INTO @TableName, @PkFieldName 
	END

	CLOSE ViewTablesCsr
	DEALLOCATE ViewTablesCsr

	--
	-- Construct an SQL clause of the form:
	-- ((Inclusions) AND (Exclusions)
	IF ISNULL(@InclusionSql, '') != '' AND ISNULL(@ExclusionSql, '') != ''
		SELECT @Sql = '((' + @InclusionSql + ') AND (' + @ExclusionSql + '))'
	ELSE IF ISNULL(@InclusionSql, '') != '' 
		SELECT @Sql = '(' + @InclusionSql + ')'
	ELSE
		SELECT @Sql = '(' + @ExclusionSql + ')'

END
GO


