IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[qIIS_GetViewFieldExplorerMapping]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[qIIS_GetViewFieldExplorerMapping]
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 25/09/2015
-- Description:	Gets the columns from the specified view and links that (via its order only) to the 
-- Called By:	eQuipCloud TBS Project but will be universal
-- Notes:
--	There is no link in the e-Quip databse that links the columns of explorer grid column to the actual columns of the view
--	Graham links them in the desktop app by binding every grid column and then hiding the columns he doesn't need
--	but he finds them by their order, i.e. if you get the Explorer Grid Column rows for a view via their ordinal value, this will
--	be the same number of rows as the view has fields / columns and also in the same order. 
-- =======================================================================================================================================
-- History:
-- v1.00	25/09/2015	Philip Brassington		Created
-- =======================================================================================================================================

CREATE PROCEDURE [dbo].[qIIS_GetViewFieldExplorerMapping]
	@ViewId INT,
	@ViewName VARCHAR(50) 
AS
BEGIN
	SET NOCOUNT ON;

	--Table Variable 
	DECLARE @GridColumns TABLE
	(
		RowNumber INT,
		ColumnId INT, 
		ViewId INT,
		ExplorerOrdinal INT, 
		ColumnHeading VARCHAR(50),
		IsPK BIT,
		RawName VARCHAR(50)
	)

	INSERT INTO @GridColumns
	SELECT ROW_NUMBER() OVER (ORDER BY Ordinal) AS RowNumber, Id, ViewId, Ordinal, ColumnHeading, IsPk, RawName FROM ExplorerGridColumn WHERE ViewId = @ViewId

	IF @ViewId = 111
	BEGIN
		SELECT gc.ColumnId, gc.ViewId, isc.TABLE_NAME AS ViewName,isc.ORDINAL_POSITION AS ViewOrdinal, gc.ExplorerOrdinal, isc.COLUMN_NAME AS FieldName, gc.ColumnHeading, isc.DATA_TYPE AS DataType, gc.IsPK 
		FROM information_schema.columns isc
		INNER JOIN @GridColumns gc ON gc.RawName = isc.COLUMN_NAME
		WHERE isc.table_name = @ViewName
		ORDER BY isc.ORDINAL_POSITION
	END
	ELSE
	BEGIN
		SELECT gc.ColumnId, gc.ViewId, isc.TABLE_NAME AS ViewName,isc.ORDINAL_POSITION AS ViewOrdinal, gc.ExplorerOrdinal, isc.COLUMN_NAME AS FieldName, gc.ColumnHeading, isc.DATA_TYPE AS DataType, gc.IsPK 
		FROM information_schema.columns isc
		INNER JOIN @GridColumns gc ON gc.RowNumber = isc.ORDINAL_POSITION
		WHERE isc.table_name = @ViewName
		ORDER BY isc.ORDINAL_POSITION
	END
END

GO


