IF NOT EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[IIS_TrainingUserManagement]'))
    EXEC('CREATE VIEW [dbo].IIS_TrainingUserManagement] AS SELECT '''' AS Col1 ')
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 18th April 2017
-- Description:	View for viewing Training account
-- Called By:	eQuipCloud Ward Users / universal, used by many
-- Notes:
--		The user could specify a different view if they chose.
--		This is used on it's name sake page within the Training Microsite
-- =======================================================================================================================================
-- History:
-- v1.00	28th November 2017	Peter Bush		Created
-- v1.01    05th December 2017  Peter Bush		Fixed issue with some managers not loading in, added IS NOT NULL Clause to both Personnel Left Joins
-- =======================================================================================================================================
--
ALTER VIEW [dbo].[IIS_TrainingUserManagement]
AS

SELECT DISTINCT
	P.PersonnelId, 
	PersonnelShortName,
	P.Payroll AS ESRNumber,
	Location.LocationShortName,
	P.EMail,
	CAST(TU.InActive AS BIT) AS TrainingAccountStatus, 
	
	CASE 
	WHEN TU.PersonnelId IS NULL THEN NULL
	WHEN CG.ResponsibleId = TU.PersonnelId THEN CAST(1 AS BIT)
	ELSE CAST(0 AS BIT)
	END AS IsManager 

FROM Personnel AS P
	LEFT JOIN CompetenceGroupPersonnel AS CGP
		ON P.PersonnelId = CGP.PersonnelId
	LEFT JOIN IIS_TrainingUser AS TU
		ON P.PersonnelId  = TU.PersonnelId 
	LEFT JOIN Location AS Location
		ON P.LocationId  = Location.LocationId
	LEFT JOIN CompetenceGroup AS CG
		ON P.PersonnelId = CG.ResponsibleId 
WHERE CG.CompetenceGroupId IS NOT NULL OR CGP.CompetenceGroupId IS NOT NULL


GO


