IF NOT EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[IIS_UserSummaryForSimple]'))
    exec('CREATE VIEW [dbo].[IIS_UserSummaryForSimple] AS SELECT '''' AS Col1 ')
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 24/11/2017
-- Description:	Get the summary grid data for the competence group
-- Called By:	eQuipCloud Training Simple Interface Only
-- Notes:
--		http://192.168.0.3:8090/display/DATACONV/Query+Information+For+IIS_GetCompGroupSummaryForSimple
-- =======================================================================================================================================
-- History:
-- v1.00	24/11/2017	Philip Brassington		Created
-- v1.01	05/12/2017	Peter Bush				Fixed values, removed and replaced test data
-- v1.02	21/08/2020  Jack Foulkes			View has been updated to simplify data that is returned
-- =======================================================================================================================================
ALTER VIEW [dbo].[IIS_UserSummaryForSimple]
AS
SELECT 
	P.PersonnelId, CG.CompetenceGroupId, CompetenceGroupShortName,
	ISNULL(P.PersonnelShortName, P.FirstName + ' ' + P.LastName) AS StaffName,

	(
		SELECT COUNT(*) FROM CompetenceGroupModel CGM
		WHERE CGM.CompetenceGroupId = CG.CompetenceGroupId
	) AS TotalTNARecords,

	(
		SELECT COUNT(*) FROM vsCompetenceGroupTNA CGTNA
		WHERE CGTNA.PersonnelId = P.PersonnelId 
		AND CGTNA.CompetenceGroupId = CG.CompetenceGroupId
		AND RequiredCompetenceTypeClassId > 0

	) AS TotalRequired,

	(
		SELECT COUNT(*) FROM vsCompetenceGroupTNA CGTNA
		WHERE CGTNA.PersonnelId = P.PersonnelId 
		AND CGTNA.CompetenceGroupId = CG.CompetenceGroupId
		AND RequiredCompetenceTypeClassId > 0
		AND RequiredCompetenceTypeClassId <= AttainedCompetenceTypeClassId
	) AS TotalAchieved

FROM Personnel P
INNER JOIN CompetenceGroupPersonnel CGP
	ON CGP.PersonnelId = P.PersonnelId
INNER JOIN CompetenceGroup CG
	ON CG.CompetenceGroupId = CGP.CompetenceGroupId
GO