IF NOT EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[IIS_vsCompetenceGroupTNA]'))
    exec('CREATE VIEW [dbo].[IIS_vsCompetenceGroupTNA] AS SELECT '''' AS Col1 ')
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 15/11/2015
-- Description:	Gets the TNA competency list, based on the e-Quip proc of the same name 
-- Called By:	eQuipCloud Training Project Only
-- Notes:
--		Based on the e-Quip view of the same name, needed the PK setting in the view and also some of the bit fields 
--		needed to be not null when returned. 
--
--		This is used to display competences related to competence groups. It is NOT used by ppgAsset
--		The INACTIVE column is used to denote an inactive:
--		Personnel recordg
--		Model record
--		CompetenceGroup record
--		CompetenceGroupPersonnel record
--		CompetenceGroupModel record
--
--	RESTRICTIONS: Works with e-Quip 3.5 onwards only (due to changes in Calculate Refresher Training
-- =======================================================================================================================================
-- History:
-- v1.00	25th September 2015	Philip Brassington	
--			Created
-- v1.1		19th December 2016	Philip Brassington 	
--			Changed to match the updated version of the e-Quip to view to account for changes to CalculateRefresherTrainingDue
-- v1.2		5th November 2019	Philip Brassington
--			Changed the PK on the second select
-- v1.3		7th June 2019 - Jack Foulkes
--			Fixed RiskLevelClassId ISNULL Order #14150	
-- v1.4		19th June 2020	Philip Brassington
--			Clean up during for new version to Barts, added in leaving date (from Warrington Version)
--			Added in admin ids from branch and location
--			
-- =======================================================================================================================================

ALTER VIEW [dbo].[IIS_vsCompetenceGroupTNA]
AS
	--
	-- Records which exist in PersonnelCompetence
	-- UNION
	-- Records which don't exist in PersonnelCompetence
	SELECT P1.PersonnelId + ',' + Model.ModelId + ',' + CG.CompetenceGroupId AS PK, 
		CG.CompetenceGroupId, 
		CompetenceGroupCode, 
		CompetenceGroupShortName, 
		CG.Validity, 
		Model.TrainingValidityMonths,
		P1.Payroll AS EmployeeNo, PC.PersonnelId, P1.PersonnelShortName,
		P1.FirstName, P1.MiddleName, P1.LastName, --3.5 improvement
		P1.StaffGradeId, StaffGradeShortName, 
		ISNULL(P1.IsProfessional, 0) AS IsProfessional,
		ISNULL(P1.MaternityLeave, 0) AS MaternityLeave,
		ISNULL(P1.LongTermLeave, 0) AS LongTermLeave,
		P1.LeavingDate,
		[Site].SiteId, SiteShortName, 
		P1.LocationId, LocationShortName, 
		P1.BranchId, BranchShortName, 
		Location.TrainingAdmin1Id As LocationTrainingAdmin1Id, Location.TrainingAdmin2Id As LocationTrainingAdmin2Id, Location.TrainingAdmin3Id As LocationTrainingAdmin3Id, 
		Location.TrainingAdmin4Id As LocationTrainingAdmin4Id, Location.TrainingAdmin5Id As LocationTrainingAdmin5Id,
		Branch.TrainingAdmin1Id As BranchTrainingAdmin1Id, Branch.TrainingAdmin2Id As BranchTrainingAdmin2Id, Branch.TrainingAdmin3Id As BranchTrainingAdmin3Id, 
		Branch.TrainingAdmin4Id As BranchTrainingAdmin4Id, Branch.TrainingAdmin5Id As BranchTrainingAdmin5Id,
		Model.BrandId, BrandShortName, 
		Model.ModelId, ModelShortName, 
		Model.CategoryId, CategoryShortName,
		ISNULL(Model.TrainingRiskId, Model.RiskLevelId) AS RiskLevelId, 
		ISNULL(TrgRisk.RiskLevelShortName, ModelRisk.RiskLevelShortName) AS RiskLevelShortName,
		ISNULL(TrgRisk.RiskLevelClassId, ModelRisk.RiskLevelClassId) AS RiskLevelClassId, 
		CT3.CompetenceTypeId AS PolicyCompetenceTypeId, 
		CT3.CompetenceTypeShortName AS PolicyCompetenceType, 
		CT3.CompetenceTypeClassId AS PolicyCompetenceTypeClassId, 
		CM.CompetenceMethodId AS PolicyCompetenceMethodId, 
		CM.CompetenceMethodShortName AS PolicyCompetenceMethod, 
		TRG.TrainingId, 
		TRG.TrainingShortName, 
		CT1.CompetenceTypeId AS RequiredCompetenceTypeId, 
		CT1.CompetenceTypeShortName AS RequiredCompetenceType, 
		CT1.CompetenceTypeClassId AS RequiredCompetenceTypeClassId, 
		CT2.CompetenceTypeId AS AttainedCompetenceTypeId, 
		CT2.CompetenceTypeShortName AS AttainedCompetenceType, 
		CT2.CompetenceTypeClassId AS AttainedCompetenceTypeClassId, 
		Trained, TrainingDate, 
		TrainerId, P2.PersonnelShortName AS Trainer,
		SelfCertified, AssessmentDate, 
		AssessorId, P3.PersonnelShortName AS Assessor, 
		DeclarationDate, EffectiveDate AS VerificationDate, 
		dbo.CalculateRefresherTrainingDue(P1.PersonnelId, Model.ModelId) AS RefresherTrainingDate, 
		PC.RefresherTrainingDate AS RefresherTrainingDate2,
		PC.PersonnelCompetenceStatusId, PersonnelCompetenceStatusShortName,
		PersonnelCompetenceStatusClassId,
		SelfCertifyHighRisk, SelfCertifyMediumRisk, SelfCertifyLowRisk, 
		ISNULL(ProfessionalsCanSelfCertify, 0) AS ProfessionalsCanSelfCertify,
		dbo.TNAItemRed(P1.PersonnelId, Model.ModelId, GETDATE()) AS Red,
		dbo.TNAItemAmber(P1.PersonnelId, Model.ModelId, GETDATE()) AS Amber,
		dbo.TNAItemGreen(P1.PersonnelId, Model.ModelId, GETDATE()) AS Green,
		CASE WHEN (ISNULL(P1.Inactive, 0) != 1 AND
			ISNULL(CG.Inactive, 0) != 1 AND
			ISNULL(Model.Inactive, 0) != 1 AND
			ISNULL(CGP.Inactive, 0) != 1 AND
			ISNULL(CGM.Inactive, 0) != 1 AND
			ISNULL(PC.Inactive, 0) != 1)
		THEN 0 
		ELSE 1 
		END AS Inactive, 
		P1.TrainingManagerId
	FROM CompetenceGroup AS CG
		INNER JOIN CompetenceGroupModel AS CGM
			ON CG.CompetenceGroupId = CGM.CompetenceGroupId
		INNER JOIN CompetenceGroupPersonnel AS CGP
			ON CG.CompetenceGroupId = CGP.CompetenceGroupId
		INNER JOIN Model
			ON CGM.ModelId = Model.ModelId
		LEFT JOIN Brand
			ON Model.BrandId = Brand.BrandId
		LEFT JOIN Category
			ON Model.CategoryId = Category.CategoryId
		LEFT JOIN RiskLevel AS ModelRisk
			ON Model.RiskLevelId = ModelRisk.RiskLevelId
		LEFT JOIN RiskLevel AS TrgRisk
			ON Model.TrainingRiskId = TrgRisk.RiskLevelId
		INNER JOIN Personnel AS P1
			ON CGP.PersonnelId = P1.PersonnelId
		LEFT JOIN StaffGrade
			ON P1.StaffGradeId = StaffGrade.StaffGradeId
		LEFT JOIN Location
			ON P1.LocationId = Location.LocationId
		LEFT JOIN [Site]
			ON Location.SiteId = Site.SiteId
		LEFT JOIN Branch
			ON P1.BranchId = Branch.BranchId
		INNER JOIN PersonnelCompetence AS PC
			ON (CGP.PersonnelId = PC.PersonnelId AND CGM.ModelId = PC.ModelId)
		LEFT JOIN Personnel AS P2
			ON PC.TrainerId = P2.PersonnelId
		LEFT JOIN Personnel AS P3
			ON PC.AssessorId = P3.PersonnelId
		LEFT JOIN CompetenceType AS CT1
			ON PC.RequiredCompetenceTypeId = CT1.CompetenceTypeId
		LEFT JOIN CompetenceType AS CT2
			ON PC.AttainedCompetenceTypeId = CT2.CompetenceTypeId
		LEFT JOIN PersonnelCompetenceStatus AS PCS
			ON PC.PersonnelCompetenceStatusId = PCS.PersonnelCompetenceStatusId
		LEFT JOIN ModelStaffGradeCompetence AS MSGC
			ON (CGM.ModelId = MSGC.ModelId AND P1.StaffGradeId = MSGC.StaffGradeId)
		LEFT JOIN CompetenceType AS CT3
			ON MSGC.CompetenceTypeId = CT3.CompetenceTypeId
		LEFT JOIN CompetenceMethod AS CM
			ON MSGC.CompetenceMethodId = CM.CompetenceMethodId
		LEFT JOIN Training AS TRG
			ON MSGC.TrainingId = TRG.TrainingId

	UNION

	SELECT P1.PersonnelId + ',' + Model.ModelId + ',' + CG.CompetenceGroupId AS PK,
		CG.CompetenceGroupId, 
		CompetenceGroupCode, 
		CompetenceGroupShortName, 
		CG.Validity, 
		Model.TrainingValidityMonths,
		P1.Payroll AS [Employee No], CGP.PersonnelId, P1.PersonnelShortName, P1.FirstName, P1.MiddleName, P1.LastName,
		CONVERT(VARCHAR(50), NULL) AS StaffGradeId, StaffGradeShortName, 
		ISNULL(P1.IsProfessional, 0) AS IsProfessional,
		ISNULL(P1.MaternityLeave, 0) AS MaternityLeave,
		ISNULL(P1.LongTermLeave, 0) AS LongTermLeave,
		P1.LeavingDate,
		[Site].SiteId, SiteShortName, 
		P1.LocationId, LocationShortName, 
		P1.BranchId, BranchShortName, 
		Location.TrainingAdmin1Id As LocationTrainingAdmin1Id, Location.TrainingAdmin2Id As LocationTrainingAdmin2Id, Location.TrainingAdmin3Id As LocationTrainingAdmin3Id, 
		Location.TrainingAdmin4Id As LocationTrainingAdmin4Id, Location.TrainingAdmin5Id As LocationTrainingAdmin5Id,
		Branch.TrainingAdmin1Id As BranchTrainingAdmin1Id, Branch.TrainingAdmin2Id As BranchTrainingAdmin2Id, Branch.TrainingAdmin3Id As BranchTrainingAdmin3Id, 
		Branch.TrainingAdmin4Id As BranchTrainingAdmin4Id, Branch.TrainingAdmin5Id As BranchTrainingAdmin5Id,
		Model.BrandId, BrandShortName, 
		Model.ModelId, ModelShortName, 
		Model.CategoryId, CategoryShortName, 
		ISNULL(Model.TrainingRiskId, Model.RiskLevelId) AS RiskLevelId, 
		ISNULL(TrgRisk.RiskLevelShortName, ModelRisk.RiskLevelShortName) AS RiskLevelShortName,
		ISNULL(TrgRisk.RiskLevelClassId, ModelRisk.RiskLevelClassId) AS RiskLevelClassId, 
		CT3.CompetenceTypeId AS PolicyCompetenceTypeId, 
		CT3.CompetenceTypeShortName AS PolicyCompetenceType, 
		CT3.CompetenceTypeClassId AS PolicyCompetenceTypeClassId, 
		CM.CompetenceMethodId AS PolicyCompetenceMethodId, 
		CM.CompetenceMethodShortName AS PolicyCompetenceMethod, 
		TRG.TrainingId, 
		TRG.TrainingShortName, 
		CONVERT(VARCHAR(50), NULL) AS RequiredCompetenceTypeId, 
		CONVERT(VARCHAR(255), NULL) AS RequiredCompetenceType, 
		CONVERT(VARCHAR(50), NULL) AS RequiredCompetenceTypeClassId, 
		CONVERT(VARCHAR(50), NULL) AS AttainedCompetenceTypeId, 
		CONVERT(VARCHAR(255), NULL) AS AttainedCompetenceType, 
		CONVERT(VARCHAR(50), NULL) AS AttainedCompetenceTypeClassId, 
		CONVERT(BIT, 0) AS Trained, 
		CONVERT(DATETIME, NULL) AS TrainingDate, 
		CONVERT(VARCHAR(50), NULL) AS TrainerId, 
		CONVERT(VARCHAR(255), NULL) AS  Trainer, 
		CONVERT(BIT, 0) AS SelfCertified,
		CONVERT(DATETIME, NULL) AS AssessmentDate, 
		CONVERT(VARCHAR(50), NULL) AS AssessorId, 
		CONVERT(VARCHAR(255), NULL) AS Assessor, 
		CONVERT(DATETIME, NULL) AS DeclarationDate, 
		CONVERT(DATETIME, NULL) AS VerificationDate, 
		CONVERT(DATETIME, NULL) AS RefresherTrainingDate, 
		CONVERT(DATETIME, NULL) AS RefresherTrainingDate2, 
		CONVERT(VARCHAR(50), NULL) AS PersonnelCompetenceStatusId, 
		CONVERT(VARCHAR(255), NULL) AS PersonnelCompetenceStatusShortName, 
		CONVERT(VARCHAR(50), NULL) AS PersonnelCompetenceStatusClassId, 
		SelfCertifyHighRisk, SelfCertifyMediumRisk, SelfCertifyLowRisk, 
		ISNULL(ProfessionalsCanSelfCertify, 0) AS ProfessionalsCanSelfCertify,
		0 AS Red,
		0 AS Amber,
		0 AS Green,
		CONVERT(BIT, 0) AS Inactive, 
		P1.TrainingManagerId
	FROM CompetenceGroup AS CG
		INNER JOIN CompetenceGroupModel AS CGM
			ON CG.CompetenceGroupId  =  CGM.CompetenceGroupId
		INNER JOIN CompetenceGroupPersonnel AS CGP
			ON CG.CompetenceGroupId = CGP.CompetenceGroupId
		INNER JOIN Personnel AS P1
			ON CGP.PersonnelId = P1.PersonnelId
		LEFT JOIN StaffGrade
			ON P1.StaffGradeId = StaffGrade.StaffGradeId
		LEFT JOIN Model
			ON CGM.ModelId = Model.ModelId
		LEFT JOIN RiskLevel AS ModelRisk
			ON Model.RiskLevelId = ModelRisk.RiskLevelId
		LEFT JOIN RiskLevel AS TrgRisk
			ON Model.TrainingRiskId = TrgRisk.RiskLevelId
		LEFT JOIN Brand
			ON Model.BrandId = Brand.BrandId
		LEFT JOIN Category
			ON Model.CategoryId = Category.CategoryId
		LEFT JOIN Training
			ON CG.TrainingId = Training.TrainingId
		LEFT JOIN Location
			ON P1.LocationId = Location.LocationId
		LEFT JOIN [Site]
			ON Location.SiteId = Site.SiteId
		LEFT JOIN Branch
			ON P1.BranchId = Branch.BranchId
		LEFT JOIN ModelStaffGradeCompetence AS MSGC
			ON (CGM.ModelId = MSGC.ModelId AND P1.StaffGradeId = MSGC.StaffGradeId)
		LEFT JOIN CompetenceType AS CT3
			ON MSGC.CompetenceTypeId = CT3.CompetenceTypeId
		LEFT JOIN CompetenceMethod AS CM
			ON MSGC.CompetenceMethodId = CM.CompetenceMethodId
		LEFT JOIN Training AS TRG
			ON MSGC.TrainingId = TRG.TrainingId
	WHERE NOT EXISTS
		(
			SELECT * 
			FROM PersonnelCompetence AS PC
			WHERE PC.ModelId = CGM.ModelId AND
				PC.PersonnelId = CGP.PersonnelId AND
				ISNULL(PC.Inactive, 0) != 1
		) AND
		ISNULL(P1.Inactive, 0) != 1 AND
		ISNULL(CG.Inactive, 0) != 1  AND
		ISNULL(Model.Inactive, 0) != 1 AND
		ISNULL(CGP.Inactive, 0) != 1 AND
		ISNULL(CGM.Inactive, 0) != 1



