IF NOT EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND OBJECT_ID = OBJECT_ID('[dbo].[IIS_ppgTNA]'))
   EXEC('CREATE PROCEDURE [dbo].[IIS_ppgTNA] AS BEGIN SET NOCOUNT ON; END')
GO
---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 10/11/2015
-- Description:	Get's the TNARecord
-- Called By:	eQuipCloud Training Only
-- Notes:
--		Based on the e-Quip proc of the same name but stripped back
-- =======================================================================================================================================
-- History:
-- v1.00	10/11/2015	Philip Brassington		Created
-- v1.01	06/06/2017	Peter Bush				Added calculating of review date
-- v1.02	27th July 2017	Philip Brassington	Changed the view from vsCompetenceGroupTNA to IIS_vsCompetenceGroupTNA and added training manager id 
-- v1.03	22nd June 2020	Philip Brassington	Added in the new branch / location admins
-- =======================================================================================================================================

ALTER PROC [dbo].[IIS_ppgTNA]
	@Pk CHAR(200)
AS
BEGIN

	-- @Pk will be a combination of "PersonnelId,ModelId,CompetenceGroupId"	
	-- "CompetenceGroupId" is ignored. It is only used when refreshing
	-- the grid after an edit
	DECLARE @PersonnelId VARCHAR(50)
	DECLARE @ModelId VARCHAR(50)

	IF PATINDEX( '%,%,%', @Pk) = 0
		RETURN 1

	DECLARE @CommaPos1 INT
	DECLARE @CommaPos2 INT

	SET @CommaPos1 = CHARINDEX( ',', @Pk, 1 )
	SET @CommaPos2 = CHARINDEX( ',', @Pk, @CommaPos1 + 1)

	SET @PersonnelId = SUBSTRING(@Pk, 1, @CommaPos1 - 1)
	SET @ModelId = SUBSTRING(@Pk, @CommaPos1 + 1, ( @CommaPos2 - @CommaPos1 ) - 1)

	--
	-- Calculate the review date. This function will call a local override
	-- if one exists
	DECLARE @CalculatedReviewDate DATETIME 
	SET @CalculatedReviewDate = dbo.CalculateRefresherTrainingDue(@PersonnelId, @ModelId)

	SELECT PersonnelId, PersonnelShortName, ModelId, ModelShortName,
		ISNULL(Validity, 0) AS Validity, 
		ISNULL(TrainingValidityMonths, 0) AS TrainingValidityMonths, 
		StaffGradeShortName,
		LocationShortName, BranchShortName,
		BrandShortName, CategoryShortName,
		PolicyCompetenceType, PolicyCompetenceTypeClassId, PolicyCompetenceMethod,
		RequiredCompetenceTypeId, RequiredCompetenceType,
		AttainedCompetenceTypeId, AttainedCompetenceType,
		ISNULL(Trained,0) AS Trained, TrainingDate, TrainerId, Trainer,
		AssessmentDate, AssessorId, Assessor, 
		ISNULL(SelfCertified,0) AS SelfCertified, DeclarationDate,
		VerificationDate, RefresherTrainingDate2 AS AlternativeReviewDate,
		RiskLevelShortName, RiskLevelClassId,
		ISNULL(SelfCertifyHighRisk, 0) AS SelfCertifyHighRisk,
		ISNULL(SelfCertifyMediumRisk, 0) AS SelfCertifyMediumRisk,
		ISNULL(SelfCertifyLowRisk, 0) AS SelfCertifyLowRisk,
		ISNULL(ProfessionalsCanSelfCertify, 0) AS ProfessionalsCanSelfCertify,
		ISNULL(IsProfessional, 0) AS IsProfessional,
		ISNULL(MaternityLeave, 0) AS MaternityLeave,
		ISNULL(LongTermLeave, 0) AS LongTermLeave,
		PersonnelCompetenceStatusId, PersonnelCompetenceStatusShortName,
		PersonnelCompetenceStatusClassId,
		@CalculatedReviewDate AS CalculatedReviewDate,
		Red, Amber, Green, TrainingManagerId, 
		LocationTrainingAdmin1Id, LocationTrainingAdmin2Id, LocationTrainingAdmin3Id, LocationTrainingAdmin4Id, LocationTrainingAdmin5Id, 
		BranchTrainingAdmin1Id, BranchTrainingAdmin2Id, BranchTrainingAdmin3Id, BranchTrainingAdmin4Id, BranchTrainingAdmin5Id
	FROM dbo.IIS_vsCompetenceGroupTNA
	WHERE PersonnelId = @PersonnelId AND
		ModelId = @ModelId

END


GO


