IF NOT EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND OBJECT_ID = OBJECT_ID('[dbo].[IIS_pppTNA]'))
   EXEC('CREATE PROCEDURE [dbo].[IIS_pppTNA] AS BEGIN SET NOCOUNT ON; END')
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 10/11/2015
-- Description:	Puts / Saves changes to the TNA Record
-- Called By:	eQuipCloud Training only
-- Notes:
--		Based on the e-Quip proc of the same name 
-- =======================================================================================================================================
-- History:
-- v1.00	10/11/2015	Philip Brassington		Created
-- v1.01    13/09/2018  Jack Foulkes			Added Constraint Fixes
-- =======================================================================================================================================
ALTER PROC [dbo].[IIS_pppTNA]
	@Pk CHAR(50),
	@PersonnelId VARCHAR(50),
	@ModelId VARCHAR(50),
	@RequiredCompetenceTypeId VARCHAR(50),
	@AttainedCompetenceTypeId VARCHAR(50),
	@PersonnelCompetenceStatusId VARCHAR(50),
	@DeclarationDate DATETIME,
	@VerificationDate DATETIME, 
	@Trained BIT,
	@TrainingDate DATETIME,
	@TrainerId VARCHAR(50),
	@SelfCertified BIT,
	@AssessmentDate DATETIME,
	@AssessorId VARCHAR(50),
	@AlternativeReviewDate DATETIME
AS
BEGIN

	-- Start of Constraint Fixes
	-- If an Id is passed in as 'None' then set to NULL

	IF ISNULL(@RequiredCompetenceTypeId, 'None') = 'None'
	BEGIN
		SET @RequiredCompetenceTypeId = NULL
	END
	
	IF ISNULL(@AttainedCompetenceTypeId, 'None') = 'None'
	BEGIN
		SET @AttainedCompetenceTypeId = NULL
	END

	IF ISNULL(@TrainerId, 'None') = 'None'
	BEGIN
		SET @TrainerId = NULL
	END

	IF ISNULL(@AssessorId, 'None') = 'None'
	BEGIN
		SET @AssessorId = NULL
	END

	IF ISNULL(@PersonnelCompetenceStatusId, 'None') = 'None'
	BEGIN
		SET @PersonnelCompetenceStatusId = NULL
	END

	--End of Constraint Fixes


	IF NOT EXISTS 
		(SELECT * FROM PersonnelCompetence
		 WHERE PersonnelId = @PersonnelId AND ModelId = @ModelId)
	BEGIN
		INSERT INTO PersonnelCompetence
			(PersonnelId, ModelId, RequiredCompetenceTypeId, AttainedCompetenceTypeId, 
			Trained, TrainingDate, TrainerId, AssessmentDate, 
			AssessorId, SelfCertified, EffectiveDate, RefresherTrainingDate, 
			ModificationDate, DeclarationDate, PersonnelCompetenceStatusId, 
			Inactive)
		VALUES
			(@PersonnelId, @ModelId, @RequiredCompetenceTypeId, @AttainedCompetenceTypeId, 
			@Trained, @TrainingDate, @TrainerId, @AssessmentDate, 
			@AssessorId, @SelfCertified, @VerificationDate, @AlternativeReviewDate, 
			GETDATE(), @DeclarationDate, @PersonnelCompetenceStatusId, 0)
	END
	ELSE
	BEGIN
		UPDATE PersonnelCompetence
		SET EffectiveDate = @VerificationDate, 
			DeclarationDate = @DeclarationDate,
			RequiredCompetenceTypeId = @RequiredCompetenceTypeId,
			AttainedCompetenceTypeId = @AttainedCompetenceTypeId,
			SelfCertified =	@SelfCertified,
			Trained = @Trained,
			TrainingDate = @TrainingDate,
			TrainerId =	@TrainerId,
			RefresherTrainingDate = @AlternativeReviewDate,
			AssessmentDate = @AssessmentDate,
			AssessorId = @AssessorId,
			PersonnelCompetenceStatusId = @PersonnelCompetenceStatusId,
			ModificationDate = GETDATE()
		WHERE PersonnelId = @PersonnelId AND
			ModelId = @ModelId
	END
END