IF NOT EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND OBJECT_ID = OBJECT_ID('[dbo].[IIS_GetStaffTNAStatsForGroup]'))
   EXEC('CREATE PROCEDURE [dbo].[IIS_GetStaffTNAStatsForGroup] AS BEGIN SET NOCOUNT ON; END')
GO
-- =======================================================================================================================================
-- Author:		Jack Foulkes
-- Create date: 25/08/2020
-- Description:	Get's a single users name, competence group and report infomation
-- Called By:	eQuipCloud Training Only
-- Notes:		Must return the following:
--					Name of Staff | Name of Competence Group | 5 Report columns i.e Report 1/2/3/4/5
-- =======================================================================================================================================
-- History:
--	25/08/2020 - Jack Foulkes
--		Created
-- =======================================================================================================================================

ALTER PROC [dbo].[IIS_GetStaffTNAStatsForGroup]
	@PersonnelId NVARCHAR(50),
	@CompetenceGroupId NVARCHAR(50)
AS
BEGIN
	SET NOCOUNT ON

	--
	-- RETURNS
	-- 0 - Success
	-- 1 - Null Parameters

	--
	-- PersonnelId & CompetenceGroupId Required
	IF ISNULL(@PersonnelId, '') = ''
		RETURN 1

	IF ISNULL(@CompetenceGroupId, '') = ''
		RETURN 1


	--
	-- Return data We will use these variables to hold the data and select from it at the end.
	DECLARE @StaffName NVARCHAR(255),
		@CompetenceGroupShortName NVARCHAR(255),
		@Report1 NVARCHAR(MAX),
		@Report2 NVARCHAR(MAX),
		@Report3 NVARCHAR(MAX),
		@Report4 NVARCHAR(MAX),
		@Report5 NVARCHAR(MAX)

	--
	-- Insert Persons Name
	SELECT TOP 1 @StaffName = ISNULL(PersonnelShortName, ISNULL(FirstName, '') + ISNULL(LastName, ''))
	FROM [Personnel]
	WHERE PersonnelId = @PersonnelId

	--
	-- Competence Group Name
	SELECT TOP 1 @CompetenceGroupShortName = CompetenceGroupShortName FROM CompetenceGroup
	WHERE CompetenceGroupId = @CompetenceGroupId

	--
	-- Build Reports

	-- Report 1
	SELECT @Report1 = COUNT(*) FROM CompetenceGroupModel CGM WHERE CGM.CompetenceGroupId = @CompetenceGroupId

	-- Report 2
	SELECT @Report2 = COUNT(*) FROM vsCompetenceGroupTNA CGTNA
	WHERE CGTNA.PersonnelId = @PersonnelId 
	AND CGTNA.CompetenceGroupId = @CompetenceGroupId
	AND RequiredCompetenceTypeClassId > 0

	-- Report 3
	--SELECT @Report3 = 0

	-- Report 4
	SELECT @Report4 = COUNT(*) FROM vsCompetenceGroupTNA CGTNA
	WHERE CGTNA.PersonnelId = @PersonnelId 
	AND CGTNA.CompetenceGroupId = @CompetenceGroupId
	AND RequiredCompetenceTypeClassId > 0
	AND RequiredCompetenceTypeClassId <= AttainedCompetenceTypeClassId

	-- Report 5
	SELECT @Report5 = CAST((NULLIF(@Report4, 0) * 100) / NULLIF(@Report2, 0) AS NVARCHAR(MAX))

	--
	-- Return results
	SELECT @StaffName AS StaffName,
		@CompetenceGroupShortName AS CompetenceGroupShortName,
		ISNULL(@Report1, 0) AS Report1,
		ISNULL(@Report2, 0) AS Report2,
		ISNULL(@Report3, 0) AS Report3,
		ISNULL(@Report4, 0) AS Report4,
		ISNULL(@Report5, 0) AS Report5

	RETURN 0
END
GO