IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[IIS_MaintainanceEventsSublist]'))
DROP VIEW [dbo].[IIS_MaintainanceEventsSublist]
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 20th June 2017
-- Description:	gets a list of asset maintainance events
-- Called By:	eQuipCloud Ward Users Asset Screen
-- Notes:
--		Based on the query in ppgAsset that returns the maintainance events. 
--		Sublist data is created using a view in the web apps, it has to be this way. 
--		there is no view for main events in e-Quip, they are created from the model. 
--
--
-- =======================================================================================================================================
-- History:
-- v1.00	20th June 2017	Philip Brassington	
--			Created
-- 
-- =======================================================================================================================================
CREATE VIEW IIS_MaintainanceEventsSublist
AS
SELECT Equipment.EquipmentId, MaintenanceEventId, ME.ModelEventId, ModelEvent.ModelEventCode,
			ModelEventShortName, FrequencyWeeks, SnapWeeks, DueDate, CompletionDate, 
			ME.JobId, JobCode, ME.PersonnelId, PersonnelShortName 
		FROM Equipment INNER JOIN MaintenanceEvent AS ME
				ON Equipment.EquipmentId = ME.EquipmentId
			LEFT JOIN Job
				ON ME.JobId = Job.JobId
			LEFT JOIN Personnel
				ON ME.PersonnelId = Personnel.PersonnelId
			INNER JOIN ModelEvent
				ON Me.ModelEventId = ModelEvent.FixedKey
GO

