IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[IIS_SparePartJob]'))
DROP VIEW [dbo].[IIS_SparePartJob]
GO

-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 18th April 2017
-- Description:	View for spare parts list on job screen
-- Called By:	eQuipCloud Ward Users / universal, used by many
-- Notes:
--		The user could specify a different view if they chose.
-- =======================================================================================================================================
-- History:
-- v1.00	18th April 2017	Philip Brassington		Created
-- v1.01	14th July 2017	Philip Brassington		Removed ByModel Column
-- =======================================================================================================================================
--
CREATE VIEW [dbo].[IIS_SparePartJob]
AS
SELECT 
	SparePartJobId, 
	SparePart.SparePartId, 
	JobId, 
	SparePartCode, 
	PartNo, 
	CASE 
	WHEN SparePart.SparePartId IS NULL THEN NonStockPart
	ELSE SparePartShortName
	END AS SparePartShortName, 
	Quantity, 
	SPJ.SparePartLocationId,
	CASE 
	WHEN SPJ.SparePartLocationId IS NULL THEN ''
	ELSE ISNULL(SparePartLocationCode, '') + ' : ' + ISNULL(LocationShortName, '')
	END AS Bin, 
	UnitPrice, 
	UnitPriceVAT, 
	ISNULL(SPJ.Quantity, 0) * ISNULL(SPJ.UnitPrice, 0) AS Total,
	ISNULL(SPJ.Quantity, 0) * ( ISNULL(SPJ.UnitPrice, 0) * ( 1 + (ISNULL(SPJ.UnitPriceVAT, 0) / 100 ))) AS TotalGross,
	OrderNo, 
	DateUsed, 
	SPJ.BudgetId, 
	BudgetShortName, 
	Notes,
	SPJ.SparePartJobStatusId, 
	SparePartJobStatusShortName, 
	RecommendStock, 
	SPJ.Billable 
FROM SparePartJob AS SPJ
	LEFT JOIN SparePart 
		ON SPJ.SparePartId  = SparePart.SparePartId
	LEFT JOIN SparePartLocation 
		ON (
			SPJ.SparePartLocationId = SparePartLocation.FixedKey AND 
			SPJ.SparePartId = SparePartLocation.SparePartId
			)
	LEFT JOIN Location 
		ON SparePartLocation.LocationId = Location.LocationId
	LEFT JOIN Budget
		ON SPJ.BudgetId = Budget.BudgetId
	LEFT JOIN SparePartJobStatus
		ON SPJ.SparePartJobStatusId = SparePartJobStatus.SparePartJobStatusId



GO


