IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[IIS_qGetLinkedDocuments]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[IIS_qGetLinkedDocuments]
GO
-- =======================================================================================================================================
-- Author:		Philip Brassington
-- Create date: 18th April 2017
-- Description:	Gets documents and inherited documents for an entity
-- Called By:	eQuipCloud Ward Users / universal, used by many
-- Notes:
--		Based on the e-Quip proc of the same name with different return values
-- =======================================================================================================================================
-- History:
-- v1.00	18th April 2017	Philip Brassington		Created
-- v1.01	20th April 2017 Philip Brassington		Added IsEmbedded Bit Column
-- =======================================================================================================================================


CREATE PROC [dbo].[IIS_qGetLinkedDocuments]
	@SqlViewId INT,
	@Pk VARCHAR(100),
	@EntityTypeId INT
AS
BEGIN
	SELECT CONVERT(VARCHAR(50), NULL) AS DocumentId
	INTO #T1
 
	DECLARE @SQL VARCHAR(8000)
	DECLARE @Viewname varchar(512)
	DECLARE @TableName VARCHAR(255)
	DECLARE @ViewPKFieldName VARCHAR(255)
	DECLARE @PKFieldName VARCHAR(255)

	IF @SqlViewId = '178'
	BEGIN
		--
		-- TNA does not support document inheritance
		GOTO SkipCursor
	END
	ELSE
	BEGIN
		SELECT @ViewName = ISNULL(ViewName, ''), @ViewPKFieldName = ISNULL(PKFieldName, '') 
		FROM ExplorerSqlView
		WHERE SqlViewId = @SqlViewId
	END

	DECLARE Csr CURSOR
	FOR
	SELECT TableName, PKFieldName
	FROM ExplorerSqlViewTable
	WHERE SqlViewId = @SqlViewId AND 
		ISNULL(Ordinal, 0) > 0 AND
		TableName != 'ParentSite'
	ORDER BY Ordinal

	OPEN Csr

	FETCH NEXT FROM Csr
	INTO @TableName, @PKFieldName

	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @SQL = 'INSERT INTO #T1 
			SELECT ExplorerDocumentLink.DocumentId FROM ExplorerDocumentLink INNER JOIN ' + @ViewName +
			' ON ExplorerDocumentLink.EntityId = ' + @ViewName + '.' + @PKFieldName 	+
			' WHERE ' + @ViewPKFieldName + ' = ' + CHAR(39) + @Pk + CHAR(39) + ' AND 
				EntityTypeId = (SELECT TOP 1 [Id] FROM ExplorerEntityType 
					WHERE TableName = ' + CHAR(39) + @TableName + CHAR(39) + ')'
print @SQL
		EXEC( @SQL )

		--
		-- Next table
		FETCH NEXT FROM Csr
		INTO @TableName, @PKFieldName
	END

	CLOSE Csr
	DEALLOCATE Csr

	--
	-- For assets & jobs open any documents associated with hazards
	DECLARE @HazardId VARCHAR(50)

	IF @SqlViewId = 5
	BEGIN
		--
		-- Get all hazards associated with this device
		DECLARE HazCsr CURSOR
		FOR 
		SELECT HazardId
		FROM HazardEquipment
		WHERE EquipmentId = @Pk
		UNION
		SELECT HazardId
		FROM HazardEquipment2
		WHERE EquipmentId = @Pk

		OPEN HazCsr

		FETCH NEXT FROM HazCsr
		INTO @HazardId

		WHILE @@FETCH_STATUS = 0
		BEGIN
			--
			-- Get the documents for this hazard
			INSERT INTO #T1 
			SELECT DocumentId 
			FROM ExplorerDocumentLink
			WHERE EntityTypeId = 40 AND
				EntityId = @HazardId				

			--
			-- Next hazard
			FETCH NEXT FROM HazCsr
			INTO @HazardId
		END

		CLOSE HazCsr
		DEALLOCATE HazCsr
	END
	ELSE IF @SqlViewId = 18
	BEGIN
		--
		-- Get all hazards associated with this device
		DECLARE HazCsr CURSOR
		FOR 
		SELECT HazardEquipment.HazardId
		FROM HazardEquipment INNER JOIN Job
			ON HazardEquipment.EquipmentId = Job.EquipmentId
		WHERE JobId = @Pk
		UNION
		SELECT HazardEquipment2.HazardId
		FROM HazardEquipment2 INNER JOIN Job
			ON HazardEquipment2.EquipmentId = Job.EquipmentId
		WHERE JobId = @Pk

		OPEN HazCsr

		FETCH NEXT FROM HazCsr
		INTO @HazardId

		WHILE @@FETCH_STATUS = 0
		BEGIN
			--
			-- Get the documents for this hazard
			INSERT INTO #T1 
			SELECT DocumentId 
			FROM ExplorerDocumentLink
			WHERE EntityTypeId = 40 AND
				EntityId = @HazardId				

			--
			-- Next hazard
			FETCH NEXT FROM HazCsr
			INTO @HazardId
		END

		CLOSE HazCsr
		DEALLOCATE HazCsr
	END

SkipCursor:
	--inherited docs, they have the brackets around them
	SELECT DISTINCT Doc.DocumentId, 
		'(' + LTRIM(RTRIM(DocumentCode)) + ')' AS DocumentCode, 
		DocumentShortName, 
		DocumentTypeShortName, 
		CONVERT(VARCHAR(8000), DocumentLongName) AS DocumentFullName, 
		CONVERT(VARCHAR(8000), DocumentDescription ) AS DocumentDescription, 
		DocumentIssueDate, 
		DocumentVersion, 
		Doc.CreationDate, 
		Doc.ModificationDate, 
		CONVERT(VARCHAR(8000), Author) AS Author, 
		CONVERT(VARCHAR(8000), DocumentPath ) AS DocumentPath, 
		CONVERT(VARCHAR(500), DocumentLocation ) AS DocumentLocation, 
		DocumentClassShortName, 
		NULL AS DocumentLinkId,
		IsWebDocument,
		CASE WHEN Doc.DocumentData IS NULL THEN CAST(0 AS BIT) ELSE CAST(1 AS BIT) END AS EmbeddedDocument
	FROM #T1 
		INNER JOIN ExplorerDocument AS Doc
			ON #T1.DocumentId = Doc.DocumentId
		LEFT JOIN ExplorerDocumentClass 
			ON Doc.DocumentClassId = ExplorerDocumentClass.DocumentClassId
		LEFT JOIN ExplorerDocumentType 
			ON Doc.DocumentTypeId = ExplorerDocumentType.DocumentTypeId
	WHERE ISNULL(Doc.Inactive, 0) != 1
	UNION
	--direct from the entity in question
	SELECT Doc.DocumentId, 
		DocumentCode, 
		DocumentShortName, 
		DocumentTypeShortName, 
		CONVERT(VARCHAR(8000), DocumentLongName) AS DocumentFullName, 
		CONVERT(VARCHAR(8000), DocumentDescription ) AS DocumentDescription, 
		DocumentIssueDate, 
		DocumentVersion, 
		Doc.CreationDate, 
		Doc.ModificationDate, 
		CONVERT(VARCHAR(8000), Author) AS Author, 
		CONVERT(VARCHAR(8000), DocumentPath ) AS DocumentPath, 
		CONVERT(VARCHAR(500), DocumentLocation ) AS DocumentLocation, 
		DocumentClassShortName, 
		DocumentLinkId,
		IsWebDocument, 
		CASE WHEN Doc.DocumentData IS NULL THEN CAST(0 AS BIT) ELSE CAST(1 AS BIT) END AS EmbeddedDocument
	FROM ExplorerDocument AS Doc 
		INNER JOIN ExplorerDocumentLink AS DocLink
			ON Doc.DocumentId = DocLink.DocumentId
		LEFT JOIN ExplorerDocumentClass 
			ON Doc.DocumentClassId = ExplorerDocumentClass.DocumentClassId
		LEFT JOIN ExplorerDocumentType 
			ON Doc.DocumentTypeId = ExplorerDocumentType.DocumentTypeId
	WHERE EntityId = @Pk AND
		EntityTypeId = @EntityTypeId AND
		ISNULL(Doc.Inactive, 0) != 1
	ORDER BY DocumentCode

END






